﻿// Script for calling enfuse.exe
// download enfuse from http://enblend.sourceforge.net/
//
// This is a script for Directory Opus.
// See http://www.gpsoft.com.au/DScripts/redirect.asp?page=scripts for development information.
// 
// Called by Directory Opus to initialize the script

var resourceMtnName = "enfuse";
var resourceMtnKey = "enfuse_ExePath";

var doFsu = DOpus.FSUtil;

function OnInit(initData)
{
	initData.name = "Enfuse";
	initData.desc = "Enfuse selected images";
	initData.copyright = "wowbagger";
	initData.version = "1.3";
	initData.default_enable = false;
  // variable for enabling debug, so as to enable debug via a button
  initData.config.DebugEnableVar = "$glob:debug"
  initData.config.DEBUG = true
  
  initData.config.EnfuseExePath = "C:\\bin\\enfuse\\bin\\enfuse.exe";
  initData.config.HideRuntime = false;
  
  //To blend an exposure stack:
  //enfuse -o output.tif input1.tif input2.tif
  initData.config.ExposureStackParams = ""; //Default option
    
  //To blend a focus stack to form an extended depth-of-field image:
  //enfuse -o output.tif --wExposure=0.001 --wSaturation=0.001 --wContrast=1 --HardMask input1.tif input2.tif ...
  initData.config.FocusStackParams = "--exposure-weight=0.001 --saturation-weight=0.001 --contrast-weight=1 --hard-mask";
  
  //Default value for the customise dialog
  initData.config.CustomDefaultParams = "--exposure-weight=1 --saturation-weight=0.2 --contrast-weight=0 --exposure-mu=0.5 --soft-mask";
  
  //User pattern
  initData.config.UserDefaultParams = "--exposure-weight=0.001 --saturation-weight=1 --contrast-weight=0 --exposure-mu=.9 --hard-mask";
  
	var cmd = initData.AddCommand();
	cmd.name = "EnfuseSelectedFiles";
	cmd.method = "OnEnfuseSelectedFiles";
	cmd.desc = "Enfuses selected files ";
	cmd.label = "Enfuse Selected Files";
	cmd.template = "FocusStack/O,Userdefined/O,CustomPrams/KO";
}

function IsDebugEnabled()
{
  return Script.config.DEBUG || doCmd.IsSet(Script.config.DebugEnableVar);
}

function LogMessage(message)
{
  if (IsDebugEnabled()) { DOpus.OutputString(message)};
}
  
// Implement the CustomCommand command
function OnEnfuseSelectedFiles(funcData)
{
  //var exposureStack = funcData.func.args.got_arg.ExposureStack ? funcData.func.args.ExposureStack : false; 
  var focusStack = funcData.func.args.got_arg.FocusStack ? funcData.func.args.FocusStack : false; 
  var userDefined = funcData.func.args.got_arg.Userdefined ? funcData.func.args.Userdefined : false; 
  var customPrams = funcData.func.args.got_arg.CustomPrams ? funcData.func.args.CustomPrams : null; 
  
  var params;
  if(customPrams)
  {
    params = customPrams;
  }
  else if (userDefined)
  {
    params = Script.config.UserDefaultParams;
  }
  else if (focusStack)
  {
    params = Script.config.FocusStackParams;
  }
  else
  {
    params = Script.config.ExposureStackParams; //Default option
  }
    
  var doCmd = DOpus.NewCommand;
	var objEnum = new Enumerator( funcData.func.sourcetab.selected_files );
  
  var targetPath;
  var fileNames = "";
    
  while (!objEnum.atEnd())
  {
    var file = objEnum.item();
    fileNames += " \"" + file + "\"";
    if(!targetPath)
    {
      targetPath = file + ".enfuse" + dateTimeStamp(new Date()) +".tif"
    }
    objEnum.moveNext();  
  }
   
  var enfuseExePath = Script.config.EnfuseExePath;

  if(!doFsu.Exists(enfuseExePath))
  {
    LogMessage("Can't find the enfuse exe, Path: " + enfuseExePath);
    return;
  }
  
  var cmdParams = "-o \"" + targetPath + "\" " + params + fileNames + " ";
  
  var cmd = "@sync:\"" + enfuseExePath + "\" " + cmdParams;
  
  LogMessage("enfusing files target \"" + targetPath + "\" using \"" + enfuseExePath + "\"\ncmd:" + cmd);
  if(!IsDebugEnabled() && Script.config.HideRuntime)
  {
    doCmd.SetModifier("runmode", "hide");
  }

  var result = doCmd.RunCommand(cmd);
}

function dateTimeStamp(date) {
  var month = date.getMonth() + 1;
  var day = date.getDate();
  var hour = date.getHours();
  var minuites = date.getMinutes(); 
  var seconds = date.getSeconds(); 
  var dateOfString = date.getFullYear()
    + (("" + month).length < 2 ? "0" : "") + month
    + (("" + day).length < 2 ? "0" : "") + day + "T"
    + (("" + hour).length < 2 ? "0" : "") + hour
    + (("" + minuites).length < 2 ? "0" : "") + minuites;
    + (("" + seconds).length < 2 ? "0" : "") + seconds;
  return dateOfString;
}

// Called to display an About dialog for this script
function OnAboutScript(aboutData)
{
	var dlg = DOpus.Dlg();
	dlg.window = aboutData.window;
	dlg.message = "Script for calling enfuse.exe\r\ndownload enfuse from http://enblend.sourceforge.net \r\n";
	dlg.title = "About enfuse";
	dlg.buttons = "OK";
	dlg.icon = "info";
	dlg.Show();
}

